# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.remote_status200_response_shares_inner import RemoteStatus200ResponseSharesInner

class TestRemoteStatus200ResponseSharesInner(unittest.TestCase):
    """RemoteStatus200ResponseSharesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RemoteStatus200ResponseSharesInner:
        """Test RemoteStatus200ResponseSharesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RemoteStatus200ResponseSharesInner`
        """
        model = RemoteStatus200ResponseSharesInner()
        if include_optional:
            return RemoteStatus200ResponseSharesInner(
                token = '',
                share_mode = '',
                backend_mode = '',
                reserved = True,
                frontend_endpoints = [
                    ''
                    ],
                backend_endpoint = '',
                open = True,
                status = ''
            )
        else:
            return RemoteStatus200ResponseSharesInner(
        )
        """

    def testRemoteStatus200ResponseSharesInner(self):
        """Test RemoteStatus200ResponseSharesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
